##parameters=type, name
#returns -1 if status property of the Object is Public,
#and returns 1 if status property is anything other than public 
# This method is not used anywhere.
import string

#path = '/'
#path = path + string.replace( context.surl, container.REQUEST['BASE0'], '')

path = context.getInstancePath()
path = path + '/Data/' + type + '/' + name
obj = context.restrictedTraverse(path)
if obj.getProperty('Status') == 'Public':
       return 1
else:
       return -1
